@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 from celery.bin import celery
 
@@ -19,5 +19,5 @@ class Command(CeleryCommand):
     def run_from_argv(self, argv):
         argv = self.handle_default_options(argv)
         base.execute_from_commandline(
-            ['%s %s' % (argv[0], argv[1])] + argv[2:],
+            ['{0[0]} {0[1]}'.format(argv)] + argv[2:],
         )
