@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 import warnings
 
@@ -108,12 +108,12 @@ class ResultManager(ExtendedManager):
     @transaction.commit_manually
     def delete_expired(self, expires):
         """Delete all expired taskset results."""
+        meta = self.model._meta
         try:
             self.get_all_expired(expires).update(hidden=True)
             cursor = self.connection_for_write().cursor()
             cursor.execute(
-                'DELETE FROM %s WHERE hidden=%%s' % (
-                    self.model._meta.db_table, ),
+                'DELETE FROM {0.db_table} WHERE hidden=%s'.format(meta),
                 (True, ),
             )
         except:
@@ -238,9 +238,10 @@ class TaskStateManager(ExtendedManager):
             return self.expired(states, expires).update(hidden=True)
 
     def purge(self):
+        meta = self.model._meta
         cursor = self.connection_for_write().cursor()
         cursor.execute(
-            'DELETE FROM %s WHERE hidden=%%s' % (self.model._meta.db_table, ),
+            'DELETE FROM {0.db_table} WHERE hidden=%s'.format(meta),
             (True, ),
         )
         transaction.commit_unless_managed()
