@@ -1,6 +1,6 @@
 from __future__ import absolute_import, unicode_literals
 
-from datetime import timedelta
+from datetime import timedelta, datetime
 from time import time, mktime
 
 from django.core.exceptions import MultipleObjectsReturned, ValidationError
@@ -347,6 +347,14 @@ class TaskState(models.Model):
         ordering = ['-tstamp']
 
     def save(self, *args, **kwargs):
+        if self.eta is not None:
+            self.eta = datetime.utcfromtimestamp(float('%d.%s' % (
+                mktime(self.eta.timetuple()), self.eta.microsecond,
+            )))
+        if self.expires is not None:
+            self.expires = datetime.utcfromtimestamp(float('%d.%s' % (
+                mktime(self.expires.timetuple()), self.expires.microsecond,
+            )))
         super(TaskState, self).save(*args, **kwargs)
 
     def __unicode__(self):
