@@ -1,11 +1,11 @@
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 try:
     from django.conf.urls import (patterns, include, url,
                                   handler500, handler404)
 except ImportError:
-    from django.conf.urls.defaults import (patterns, include, url,  # noqa
-                                           handler500, handler404)
+    from django.conf.urls import (patterns, include, url,  # noqa
+                                  handler500, handler404)
 from django.contrib import admin
 
 admin.autodiscover()
