@@ -12,7 +12,7 @@
     <http://www.djangosnippets.org/snippets/513/> by Oliver Beattie.
 
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 from base64 import b64encode, b64decode
 from zlib import compress, decompress
@@ -24,7 +24,7 @@ from django.db import models
 try:
     from django.utils.encoding import force_text
 except ImportError:
-    from django.utils.encoding import force_unicode as force_text
+    from django.utils.encoding import force_unicode as force_text  # noqa
 
 DEFAULT_PROTOCOL = 2
 
@@ -92,7 +92,8 @@ class PickledObjectField(models.Field):
 
     def get_db_prep_lookup(self, lookup_type, value, *args, **kwargs):
         if lookup_type not in ['exact', 'in', 'isnull']:
-            raise TypeError('Lookup type %s is not supported.' % lookup_type)
+            raise TypeError(
+                'Lookup type {0} is not supported.'.format(lookup_type))
         return super(PickledObjectField, self) \
             .get_db_prep_lookup(*args, **kwargs)
 
