@@ -58,9 +58,13 @@ class Camera(Polaroid):
             heartbeat = worker.heartbeats[-1]
         except IndexError:
             return
-        return aware_tstamp(heartbeat)
+        # Check for timezone settings
+        if getattr(settings, "USE_TZ", False):
+            return aware_tstamp(heartbeat)
+        return datetime.fromtimestamp(heartbeat)
 
-    def handle_worker(self, (hostname, worker)):
+    def handle_worker(self, hostname_worker):
+        (hostname, worker) = hostname_worker
         last_write, obj = self._last_worker_write[hostname]
         if not last_write or \
                 monotonic() - last_write > self.worker_update_freq:
@@ -71,8 +75,9 @@ class Camera(Polaroid):
             self._last_worker_write[hostname] = (monotonic(), obj)
         return obj
 
-    def handle_task(self, (uuid, task), worker=None):
+    def handle_task(self, uuid_task, worker=None):
         """Handle snapshotted event."""
+        (uuid, task) = uuid_task
         if task.worker and task.worker.hostname:
             worker = self.handle_worker(
                 (task.worker.hostname, task.worker),
@@ -140,8 +145,9 @@ class Camera(Polaroid):
         _handle_tasks()
 
     def on_cleanup(self):
-        dirty = sum(self.TaskState.objects.expire_by_states(states, expires)
-                    for states, expires in self.expire_states.items())
+        expired = (self.TaskState.objects.expire_by_states(states, expires)
+                   for states, expires in self.expire_states.items())
+        dirty = sum(item for item in expired if item is not None)
         if dirty:
             debug('Cleanup: Marked %s objects as dirty.', dirty)
             self.TaskState.objects.purge()
