@@ -1,16 +1,17 @@
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 import sys
 
 from datetime import timedelta
 
+from billiard.einfo import ExceptionInfo
 from django.core.cache.backends.base import InvalidCacheBackendError
 
 from celery import result
 from celery import states
 from celery.utils import gen_unique_id
-from celery.datastructures import ExceptionInfo
 
+from djcelery.app import app
 from djcelery.backends.cache import CacheBackend
 from djcelery.tests.utils import unittest
 
@@ -24,7 +25,7 @@ class SomeClass(object):
 class test_CacheBackend(unittest.TestCase):
 
     def test_mark_as_done(self):
-        cb = CacheBackend()
+        cb = CacheBackend(app=app)
 
         tid = gen_unique_id()
 
@@ -37,7 +38,7 @@ class test_CacheBackend(unittest.TestCase):
         self.assertTrue(cb.get_result(tid), 42)
 
     def test_forget(self):
-        b = CacheBackend()
+        b = CacheBackend(app=app)
         tid = gen_unique_id()
         b.mark_as_done(tid, {'foo': 'bar'})
         self.assertEqual(b.get_result(tid).get('foo'), 'bar')
@@ -46,7 +47,7 @@ class test_CacheBackend(unittest.TestCase):
         self.assertIsNone(b.get_result(tid))
 
     def test_save_restore_delete_group(self):
-        backend = CacheBackend()
+        backend = CacheBackend(app=app)
         group_id = gen_unique_id()
         subtask_ids = [gen_unique_id() for i in range(10)]
         subtasks = map(result.AsyncResult, subtask_ids)
@@ -60,7 +61,7 @@ class test_CacheBackend(unittest.TestCase):
                                                      backend=backend))
 
     def test_is_pickled(self):
-        cb = CacheBackend()
+        cb = CacheBackend(app=app)
 
         tid2 = gen_unique_id()
         result = {'foo': 'baz', 'bar': SomeClass(12345)}
@@ -71,13 +72,13 @@ class test_CacheBackend(unittest.TestCase):
         self.assertEqual(rindb.get('bar').data, 12345)
 
     def test_mark_as_failure(self):
-        cb = CacheBackend()
+        cb = CacheBackend(app=app)
 
         einfo = None
         tid3 = gen_unique_id()
         try:
             raise KeyError('foo')
-        except KeyError, exception:
+        except KeyError as exception:
             einfo = ExceptionInfo(sys.exc_info())
             pass
         cb.mark_as_failure(tid3, exception, traceback=einfo.traceback)
@@ -86,13 +87,13 @@ class test_CacheBackend(unittest.TestCase):
         self.assertEqual(cb.get_traceback(tid3), einfo.traceback)
 
     def test_process_cleanup(self):
-        cb = CacheBackend()
+        cb = CacheBackend(app=app)
         cb.process_cleanup()
 
     def test_set_expires(self):
-        cb1 = CacheBackend(expires=timedelta(seconds=16))
+        cb1 = CacheBackend(app=app, expires=timedelta(seconds=16))
         self.assertEqual(cb1.expires, 16)
-        cb2 = CacheBackend(expires=32)
+        cb2 = CacheBackend(app=app, expires=32)
         self.assertEqual(cb2.expires, 32)
 
 
@@ -126,8 +127,11 @@ class test_MemcacheWrapper(unittest.TestCase):
             sys.stderr.write(
                 '\n* Memcache library is not installed. Skipping test.\n')
             return
-        prev_cache_cls = memcached.CacheClass
-        memcached.CacheClass = locmem.CacheClass
+        try:
+            prev_cache_cls = memcached.CacheClass
+            memcached.CacheClass = locmem.CacheClass
+        except AttributeError:
+            return
         prev_backend_module = sys.modules.pop('djcelery.backends.cache')
         try:
             from djcelery.backends.cache import cache
